@@ -14,23 +14,24 @@ textual console -v
 from __future__ import annotations
 
 from dataclasses import dataclass
+from pathlib import Path
 from typing import TYPE_CHECKING, Type, TypeVar
 
 import rich.repr
 from rich.style import Style
 
-from ._types import CallbackType
-from .geometry import Offset, Size
-from .keys import _get_key_aliases
-from .message import Message
+from textual._types import CallbackType
+from textual.geometry import Offset, Size
+from textual.keys import _get_key_aliases
+from textual.message import Message
 
 MouseEventT = TypeVar("MouseEventT", bound="MouseEvent")
 
 if TYPE_CHECKING:
-    from .dom import DOMNode
-    from .timer import Timer as TimerClass
-    from .timer import TimerCallback
-    from .widget import Widget
+    from textual.dom import DOMNode
+    from textual.timer import Timer as TimerClass
+    from textual.timer import TimerCallback
+    from textual.widget import Widget
 
 
 @rich.repr.auto
@@ -732,3 +733,36 @@ class Print(Event, bubble=False):
     def __rich_repr__(self) -> rich.repr.Result:
         yield self.text
         yield self.stderr
+
+
+@dataclass
+class DeliveryComplete(Event, bubble=False):
+    """Sent to App when a file has been delivered."""
+
+    key: str
+    """The delivery key associated with the delivery.
+    
+    This is the same key that was returned by `App.deliver_text`/`App.deliver_binary`.
+    """
+
+    path: Path | None = None
+    """The path where the file was saved, or `None` if the path is not available, for
+    example if the file was delivered via web browser.
+    """
+
+    name: str | None = None
+    """Optional name returned to the app to identify the download."""
+
+
+@dataclass
+class DeliveryFailed(Event, bubble=False):
+    """Sent to App when a file delivery fails."""
+
+    key: str
+    """The delivery key associated with the delivery."""
+
+    exception: BaseException
+    """The exception that was raised during the delivery."""
+
+    name: str | None = None
+    """Optional name returned to the app to identify the download."""
