@@ -93,23 +93,25 @@ class Input(Widget, can_focus=True):
     """A text input widget."""
 
     BINDINGS: ClassVar[list[BindingType]] = [
-        Binding("left", "cursor_left", "cursor left", show=False),
-        Binding("ctrl+left", "cursor_left_word", "cursor left word", show=False),
-        Binding("right", "cursor_right", "cursor right", show=False),
-        Binding("ctrl+right", "cursor_right_word", "cursor right word", show=False),
-        Binding("backspace", "delete_left", "delete left", show=False),
-        Binding("home,ctrl+a", "home", "home", show=False),
-        Binding("end,ctrl+e", "end", "end", show=False),
-        Binding("delete,ctrl+d", "delete_right", "delete right", show=False),
-        Binding("enter", "submit", "submit", show=False),
+        Binding("left", "cursor_left", "Move cursor left", show=False),
+        Binding("ctrl+left", "cursor_left_word", "Move cursor left a word", show=False),
+        Binding("right", "cursor_right", "Move cursor right", show=False),
         Binding(
-            "ctrl+w", "delete_left_word", "delete left to start of word", show=False
+            "ctrl+right", "cursor_right_word", "Move cursor right a word", show=False
         ),
-        Binding("ctrl+u", "delete_left_all", "delete all to the left", show=False),
+        Binding("backspace", "delete_left", "Delete character left", show=False),
+        Binding("home,ctrl+a", "home", "Go to start", show=False),
+        Binding("end,ctrl+e", "end", "Go to end", show=False),
+        Binding("delete,ctrl+d", "delete_right", "Delete character right", show=False),
+        Binding("enter", "submit", "Submit", show=False),
         Binding(
-            "ctrl+f", "delete_right_word", "delete right to start of word", show=False
+            "ctrl+w", "delete_left_word", "Delete left to start of word", show=False
         ),
-        Binding("ctrl+k", "delete_right_all", "delete all to the right", show=False),
+        Binding("ctrl+u", "delete_left_all", "Delete all to the left", show=False),
+        Binding(
+            "ctrl+f", "delete_right_word", "Delete right to start of word", show=False
+        ),
+        Binding("ctrl+k", "delete_right_all", "Delete all to the right", show=False),
     ]
     """
     | Key(s) | Description |
